aboutsummaryrefslogtreecommitdiff
path: root/azalea-protocol/src
diff options
context:
space:
mode:
Diffstat (limited to 'azalea-protocol/src')
-rwxr-xr-xazalea-protocol/src/resolver.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/azalea-protocol/src/resolver.rs b/azalea-protocol/src/resolver.rs
index 43f15dce..a21d5d9b 100755
--- a/azalea-protocol/src/resolver.rs
+++ b/azalea-protocol/src/resolver.rs
@@ -3,11 +3,11 @@
use std::net::{IpAddr, SocketAddr};
use async_recursion::async_recursion;
-use thiserror::Error;
-use trust_dns_resolver::{
+use hickory_resolver::{
config::{ResolverConfig, ResolverOpts},
Name, TokioAsyncResolver,
};
+use thiserror::Error;
use crate::ServerAddress;
@@ -30,7 +30,7 @@ pub async fn resolve_address(address: &ServerAddress) -> Result<SocketAddr, Reso
}
// we specify Cloudflare instead of the default resolver because
// trust_dns_resolver has an issue on Windows where it's really slow using the
// default resolver
let resolver = TokioAsyncResolver::tokio(ResolverConfig::cloudflare(), ResolverOpts::default());
@@ -30,7 +30,7 @@ pub async fn resolve_address(address: &ServerAddress) -> Result<SocketAddr, Reso
}
// we specify Cloudflare instead of the default resolver because
- // trust_dns_resolver has an issue on Windows where it's really slow using the
+ // hickory_resolver has an issue on Windows where it's really slow using the
// default resolver
let resolver = TokioAsyncResolver::tokio(ResolverConfig::cloudflare(), ResolverOpts::default());